@@ -14,6 +14,8 @@
 #include <QAbstractItemModel>
 #include <QTimer>
 
+#include <memory>
+
 class ItemPrivateData;
 
 namespace CalendarSupport
@@ -35,12 +37,12 @@ public:
     explicit FreeBusyItemModel(QObject *parent = nullptr);
     ~FreeBusyItemModel() override;
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
-    QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex()) const override;
-    QModelIndex parent(const QModelIndex &child) const override;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QModelIndex index(int row, int column = 0, const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] QModelIndex parent(const QModelIndex &child) const override;
+    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     void addItem(const FreeBusyItem::Ptr &freebusy);
 
@@ -49,7 +51,7 @@ public:
     void removeItem(const FreeBusyItem::Ptr &freebusy);
     void removeRow(int row);
 
-    Q_REQUIRED_RESULT bool containsAttendee(const KCalendarCore::Attendee &attendee);
+    [[nodiscard]] bool containsAttendee(const KCalendarCore::Attendee &attendee);
 
     /**
      * Queues a reload of free/busy data.
@@ -76,11 +78,11 @@ protected:
 
 private:
     // Only download FB if the auto-download option is set in config
-    void autoReload();
+    CALENDARSUPPORT_NO_EXPORT void autoReload();
 
-    void setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list);
-    void updateFreeBusyData(const FreeBusyItem::Ptr &);
+    CALENDARSUPPORT_NO_EXPORT void setFreeBusyPeriods(const QModelIndex &parent, const KCalendarCore::FreeBusyPeriod::List &list);
+    CALENDARSUPPORT_NO_EXPORT void updateFreeBusyData(const FreeBusyItem::Ptr &);
 
-    FreeBusyItemModelPrivate *const d;
+    std::unique_ptr<FreeBusyItemModelPrivate> const d;
 };
 }
